// 
// Module: DatafileAttributes
// Author: Richard Saxton
//
// Description: Concrete implementation of ArfDataServer class
// 
// Comments: 
//  
// Modifications: See ChangeLog
// 
// $Id: DatafileAttributes.h,v 1.2 2004/02/10 16:15:59 rsaxton Exp $

#ifndef DatafileAttributes_H
#define DatafileAttributes_H

/* General classes */
#include <iostream>

/* SAS-specific classes */
#include "CalServer.h"
#include "Dal.h"
#include "Tracer.h"
#include "DataSubspace.h"

/* Local Classes */

/****************************************************
 *
 * class DatafileAttributes
 *
 ***************************************************/

class DatafileAttributes 
{
public:
  
  DatafileAttributes(const string & datafile);
  
  ~DatafileAttributes();
  
  /********************************************
   *
   * Property setting routines 
   *
   ********************************************/

  void setFilter(const string & filter);

  /********************************************
   *
   * General observation/mission/instrument info
   *
   ********************************************/

  Xmm::Instrument instrumentID()   const;


  const string               datafile()            const;
  const string               instrument()          const;
  const string               telescope()           const;
  const string               datamode()            const;
  const string               observationDate()     const;
  const string               observationDateEnd()  const;
  const string               observingMode()       const;
  const string               filter  ()            const;
  const string               ppsvers ()            const;
  const int                  emdhlow ()            const;
  const int                  emdhupp ()            const;
  const int                  ccdNr ()              const;

  /**************************
   *
   * Pointing info
   *
   **************************/
  
  /* Mean s/c pointing */
  double                     rapnt()                   const ;
  double                     decpnt()                  const ;
  double                     papnt()                   const ;

  /**************************
   *
   * Timing info
   *
   **************************/

  double                     frameTime()               const ;
  double                     intrinsicFrameTime()      const ;

  /********************************************
   *
   * Selection info
   *
   ********************************************/

  const string              selectionExpression()   const;

 /* Observing mode */
  void      readWindowMode();
  Xmm::Mode getWindowMode() const;
  

private:

  void getExtensionAttributes();

  string               _datafile;

  DataSet              * _set;

  Xmm::Instrument       _instrumentID;
  string               _instrument;
  string               _telescope;
  string               _filter;
  string               _datamode;
  string               _submode;
  string               _dateobs;
  string               _dateend;
  string               _ppsvers;

  double               _rapnt;
  double               _decpnt;
  double               _papnt;
  double               _frameTime;

  int                  _emdhlow;
  int                  _emdhupp;
  int                  _ccdnr;
  string               _slctexpr;

  Xmm::Mode           _windowMode;
};

#endif
