//
// Module: PsfModel
// Author: Hassan Siddiqui
//
// Description: 
//
// Abstract representation of a PSF model.
// Allows one to test either a CalPsfModel or a DummyPsfModel
// without affecting any other code.
//
// Modifications: See ChangeLog
// 
// $Id: PsfModel.h,v 1.3 2008/04/30 16:16:19 rsaxton Exp $

#ifndef PSFMODEL_H
#define PSFMODEL_H

/* SAS-specific classes */
#include "Region.h"

class PsfModel
{
public:

  /* Virtual Destructor */
  virtual ~PsfModel(){};

  /*** NOTE: units for both x/y directions are 0.05 arcseconds ***/

  /* Return normalized PSF function at given position */
  virtual double psf( double detx, 
		      double dety) const = 0;
  
  /* Calculate integrated PSF over a square area. 
     The position of the centre
     * of the square is defined by the parameters centx and centy. */
  virtual double int_psf( double detxboxcentre, 
			  double detyboxcentre, 
			  double detxboxsize,
			  double detyboxsize) const = 0;

  virtual double rad_psf() const = 0;  // Circular only

  /* Set the appropriate energy */
  virtual void energy(double energy) = 0;

  /* Return the PSF mode */
  virtual string mode() const = 0;

  /* Set the PSF radius */
  virtual void setRadius(vector<double> radii) = 0;

  /* Set the number of grid elements */
  virtual void setNgridEls(unsigned int ngridels) = 0;

  /* Set the box shape */
  virtual void setBoxShape(ShapeBasics::ShapeType shape) = 0;

  /* Set the fast mode factor for incomplete RAW-Y extraction */
  virtual void setFastModeFactor(double factor) = 0;

  /* Set the orientation of an elliptical PSF model */
  virtual void setOrientation(double orient) = 0;

  /* Get the length of the semi-major axis from the elliptical PSF model */
  virtual double getMajorAxis(double x, double y) const = 0;

};

#endif
