//
// Module: RatioPsfModel
// Author: Richard Saxton
//
// Description: 
//
// Sets up a PSF model for a circular source box.
// It is valid for a circular source box centred on the source.
//
// Modifications: See ChangeLog
// 
// $Id: RatioPsfModel.cc,v 1.3 2007/08/16 09:51:02 rsaxton Exp $

// General classes
#include <iostream>
#include <cmath>

// SAS-specific classes
#include "Region.h"

// General utility functions
#include "errstr.h"
#include "Tracer.h"
#include "NumericalRange.h"

// Local classes
#include "RatioPsfModel.h"

/* Constructor */
RatioPsfModel::RatioPsfModel( unsigned TotalPixels ):
  _totalpixels(TotalPixels)
{
  PROC;

  /* NB: TotalPixels is the size of the source region in detector pixels */

   errstr 
    << "RatioPsfModel: constructed with "
    << " TotalPixels " << TotalPixels
    << Sas::message(Msg::App, Msg::Verbose);

  ENDPROC;
};

RatioPsfModel::~RatioPsfModel()
{
  PROC;
  errstr 
    << "RatioPsfModel destroyed."
    << Sas::message(Msg::App, Msg::Verbose);

  ENDPROC;

}

/* Return the fraction of the total represented by this box */

double RatioPsfModel::int_psf( double /* xboxcentre */, 
			  double /* yboxcentre */, 
			  double  xboxsize , 
			  double  yboxsize  ) const
{
  PROC;

     double ee = xboxsize * yboxsize / _totalpixels;

     errstr 
  	<< "Encircled energy: "<<ee
  	<< Sas::message(Msg::App, Msg::Noisy);

  RETURN ee;
}

void RatioPsfModel::energy(double /* energy */)
{
  PROC; 
  ENDPROC;
}

void RatioPsfModel::setRadius(vector<double> /* radii */)
{
  PROC; 
  ENDPROC;
}

void RatioPsfModel::setNgridEls(unsigned int /* NGridEls */)
{
  PROC; 
  ENDPROC;
}

double RatioPsfModel::psf(double /* x */,
                     double /* y */) const
{
  PROC; 

   /* Do nothing */
  RETURN 1.0;
}

string RatioPsfModel::mode() const
{
  PROC; 

  RETURN "RATIO";
}
double RatioPsfModel::rad_psf() const
{
  PROC;
  RETURN 1.0;
}
void RatioPsfModel::setBoxShape( ShapeBasics::ShapeType shape ) 
{
  PROC;

    errstr<<"Shape type "<<shape
    << Sas::message(Msg::App, Msg::Verbose);

  ENDPROC;
}
void RatioPsfModel::setFastModeFactor(double factor)
{
  PROC;
                                                                                
    errstr<<"Fast mode factor "<<factor
    << Sas::message(Msg::App, Msg::Verbose);
                                                                                
  ENDPROC;
}
